@@ -18,15 +18,19 @@ class Command(NoArgsCommand):
         if not app_id:
             raise Exception("No OPENEXCHANGERATES_APP_ID defined in settings")
 
-        base_currency = 'EUR'
+        base_currency = getattr(settings, "CURRENCY_RATES_DEFAULT_CODE", 'EUR')
 
         url = CURRENT_RATES_URL + "?app_id=" + app_id
         f = urllib2.urlopen(url)
         data = json.loads(f.read())
 
-        base_currency_rate = Decimal(str(data['rates'][base_currency]))
+        # USD is the default in OpenExchangeRates, so we don't need conversion
+        if base_currency != "USD":
+            base_currency_rate = Decimal(str(data['rates'][base_currency]))
+            conversion = lambda x: Decimal(str(x)) / base_currency_rate
+        else:
+            conversion = lambda x: x
 
-        conversion = lambda x: Decimal(str(x)) / base_currency_rate
         date = datetime.date.fromtimestamp(data['timestamp'])
 
         ExchangeRate.objects.filter(date=date).delete()
