@@ -1,5 +1,6 @@
 import datetime
 from django.db import models
+from django.conf import settings
 from django.utils.translation import gettext_lazy as _
 
 
@@ -9,8 +10,9 @@ def default_currency():
     except Currency.DoesNotExist:
         pass
 
+    DEFAULT_CODE = getattr(settings, "CURRENCY_RATES_DEFAULT_CODE", 'EUR')
     try:
-        return Currency.objects.get(code='EUR')
+        return Currency.objects.get(code=DEFAULT_CODE)
     except Currency.DoesNotExist:
         pass
 
@@ -49,6 +51,21 @@ class Currency(models.Model):
         except ExchangeRate.DoesNotExist:
             return None
 
+    def to_default(self, value):
+        """
+        Convert a value in the current currency to the value in the default currenty.
+        """
+        return self.to_currency(value, default_currency())
+
+    def to_currency(self, value, currency):
+        """
+        Convert an value in the current currency to the value in the given currency.
+        """
+        result = value / self.current_rate()
+        if not currency.is_default:
+            result *= currency.current_rate()
+        return result
+
 
 class ExchangeRate(models.Model):
     currency = models.ForeignKey(Currency, related_name='rates')
